jupyter_threejs_sage: Sage: Open Source Mathematics Software: Jupyter extension for 3D graphics with threejs
============================================================================================================

Description
-----------

Sage: Open Source Mathematics Software: Jupyter extension for 3D graphics with threejs

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/jupyter-threejs-sage/

